@@ -4,33 +4,23 @@
     SPDX-FileCopyrightText: 2022 Nate Graham <nate@kde.org>
 */
 
-#include <KAboutData>
-#include <KLocalizedString>
 #include <KPluginFactory>
-#include <KQuickAddons/ConfigModule>
+#include <KQuickConfigModule>
 #include <QLibraryInfo>
 
 #include <CommandOutputContext.h>
 
-class KCMKWinSupportInfo : public KQuickAddons::ConfigModule
+class KCMKWinSupportInfo : public KQuickConfigModule
 {
     Q_OBJECT
 public:
-    explicit KCMKWinSupportInfo(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-        : ConfigModule(parent, data, args)
+    explicit KCMKWinSupportInfo(QObject *parent, const KPluginMetaData &data)
+        : KQuickConfigModule(parent, data)
     {
         auto outputContext = new CommandOutputContext(QLibraryInfo::location(QLibraryInfo::BinariesPath) + QStringLiteral("/qdbus"),
                                                       {QStringLiteral("org.kde.KWin"), QStringLiteral("/KWin"), QStringLiteral("supportInformation")},
                                                       parent);
         qmlRegisterSingletonInstance("org.kde.kinfocenter.kwinsupportinfo.private", 1, 0, "InfoOutputContext", outputContext);
-
-        auto *about = new KAboutData(QStringLiteral("kcm_kwinsupportinfo"),
-                                     i18nc("@label kcm name", "Window Manager"),
-                                     QStringLiteral("1.0"),
-                                     QString(),
-                                     KAboutLicense::GPL);
-        about->addAuthor(i18n("Nate Graham"), QString(), QStringLiteral("nate@kde.org"));
-        setAboutData(about);
     }
 };
 
