@@ -5,26 +5,20 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#include <KAboutData>
-#include <KLocalizedString>
 #include <KPluginFactory>
-#include <KQuickAddons/ConfigModule>
+#include <KQuickConfigModule>
 
 #include <CommandOutputContext.h>
 
-class KCMOpenCL : public KQuickAddons::ConfigModule
+class KCMOpenCL : public KQuickConfigModule
 {
     Q_OBJECT
 public:
-    explicit KCMOpenCL(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-        : ConfigModule(parent, data, args)
+    explicit KCMOpenCL(QObject *parent, const KPluginMetaData &data)
+        : KQuickConfigModule(parent, data)
     {
         auto outputContext = new CommandOutputContext(QStringLiteral("clinfo"), {}, parent);
         qmlRegisterSingletonInstance("org.kde.kinfocenter.opencl.private", 1, 0, "InfoOutputContext", outputContext);
-
-        auto *about = new KAboutData(QStringLiteral("kcm_opencl"), i18nc("@label kcm name", "OpenCL"), QStringLiteral("1.0"), QString(), KAboutLicense::GPL);
-        about->addAuthor(i18n("Linus Dierheimer"), QString(), QStringLiteral("linus@dierheimer.de"));
-        setAboutData(about);
     }
 };
 
