@@ -3,26 +3,20 @@
     SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
 */
 
-#include <KAboutData>
-#include <KLocalizedString>
 #include <KPluginFactory>
-#include <KQuickAddons/ConfigModule>
+#include <KQuickConfigModule>
 
 #include <CommandOutputContext.h>
 
-class KCMVulkan : public KQuickAddons::ConfigModule
+class KCMVulkan : public KQuickConfigModule
 {
     Q_OBJECT
 public:
-    explicit KCMVulkan(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-        : ConfigModule(parent, data, args)
+    explicit KCMVulkan(QObject *parent, const KPluginMetaData &data)
+        : KQuickConfigModule(parent, data)
     {
         auto outputContext = new CommandOutputContext(QStringLiteral("vulkaninfo"), {}, parent);
         qmlRegisterSingletonInstance("org.kde.kinfocenter.vulkan.private", 1, 0, "InfoOutputContext", outputContext);
-
-        auto *about = new KAboutData(QStringLiteral("kcm_vulkan"), i18nc("@label kcm name", "Vulkan"), QStringLiteral("1.0"), QString(), KAboutLicense::GPL);
-        about->addAuthor(i18n("Harald Sitter"), QString(), QStringLiteral("sitter@kde.org"));
-        setAboutData(about);
     }
 };
 
