@@ -1,11 +1,13 @@
 /*
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2021-2022 Harald Sitter <sitter@kde.org>
 */
 
 #pragma once
 
+#include <QMap>
 #include <QObject>
+#include <QUrl>
 
 // Somewhat general-purpose command executor. This class runs the executable with arguments, collecting all its output
 // and potentially filtering it to limit the lines to only ones matching.
@@ -22,8 +24,13 @@ class CommandOutputContext : public QObject
     Q_PROPERTY(bool ready MEMBER m_ready NOTIFY readyChanged)
     // Potential error description. Empty when there is no error to report.
     Q_PROPERTY(QString error MEMBER m_error NOTIFY errorChanged)
+    // Extra explanatory text for error conditions. Empty when no explanatory text has been specified.
+    Q_PROPERTY(QString explanation MEMBER m_explanation NOTIFY explanationChanged)
+    // URL where the user can report a bug when there is an error. Empty when there is no error, or no applicable place to report a bug
+    Q_PROPERTY(QUrl bugReportUrl MEMBER m_bugReportUrl CONSTANT)
 public:
-    explicit CommandOutputContext(const QString &executable, const QStringList &arguments, QObject *parent = nullptr);
+    CommandOutputContext(const QStringList &findExecutables, const QString &executable, const QStringList &arguments, QObject *parent = nullptr);
+    CommandOutputContext(const QString &executable, const QStringList &arguments, QObject *parent = nullptr);
 
     QString executableName() const;
     QStringList arguments() const;
@@ -36,21 +43,25 @@ Q_SIGNALS:
     void textChanged();
     void readyChanged();
     void errorChanged();
+    void explanationChanged();
 
 private:
     void reset();
     void load();
-    void setError(const QString &message);
+    void setError(const QString &message, const QString &explanation);
     void setReady();
 
     const QString m_executableName;
     QString m_executablePath;
+    QMap<QString, QString> m_foundExecutablePaths;
     const QStringList m_arguments;
+    const QUrl m_bugReportUrl;
 
     QStringList m_originalLines;
 
     bool m_ready = false;
     QString m_error;
+    QString m_explanation;
 
     QString m_text; // possibly filtered
     QString m_filter;
